# -*- coding:utf-8 -*-

from distutils.core import setup

setup(
    name='weidian',
    version='1.0.0',
    packages=[''],
    url='http://woodpecker.rocks',
    license='',
    author='linpeng',
    author_email='linpeng1219@gmail.com',
    description='My Test'
)
